@@ -14,34 +14,37 @@ import argparse
 import dataclasses
 import json
 import typing
-
 from datetime import datetime, timedelta
 
 import prompt_toolkit
 import pytest
+from botocore.stub import Stubber
 from dateutil.tz import tzlocal
-
 from prompt_toolkit import prompt as ptk_prompt
 from prompt_toolkit.document import Document
-from prompt_toolkit.validation import Validator
-from prompt_toolkit.validation import DummyValidator
-from prompt_toolkit.validation import ValidationError
+from prompt_toolkit.validation import (
+    DummyValidator,
+    ValidationError,
+    Validator,
+)
 
-from botocore.stub import Stubber
-
-from awscli.testutils import mock, unittest
-from awscli.customizations.configure.sso import display_account
-from awscli.customizations.configure.sso import PTKPrompt
-from awscli.customizations.configure.sso import SSOSessionConfigurationPrompter
-from awscli.customizations.configure.sso import ConfigureSSOCommand
-from awscli.customizations.configure.sso import ConfigureSSOSessionCommand
-from awscli.customizations.configure.sso import StartUrlValidator
-from awscli.customizations.configure.sso import RequiredInputValidator
-from awscli.customizations.configure.sso import ScopesValidator
-from awscli.customizations.sso.utils import parse_sso_registration_scopes
-from awscli.customizations.sso.utils import do_sso_login, PrintOnlyHandler
+from awscli.customizations.configure.sso import (
+    ConfigureSSOCommand,
+    ConfigureSSOSessionCommand,
+    PTKPrompt,
+    RequiredInputValidator,
+    ScopesValidator,
+    SSOSessionConfigurationPrompter,
+    StartUrlValidator,
+    display_account,
+)
+from awscli.customizations.sso.utils import (
+    PrintOnlyHandler,
+    do_sso_login,
+    parse_sso_registration_scopes,
+)
 from awscli.formatter import CLI_OUTPUT_FORMATS
-
+from awscli.testutils import mock, unittest
 from tests import StubbedSession
 
 
@@ -681,7 +684,8 @@ class RegionPrompt(PromptWithDefault):
 @dataclasses.dataclass
 class OutputPrompt(PromptWithDefault):
     msg_format: str = dataclasses.field(
-        init=False, default="CLI default output format (json if not specified) [{default}]: "
+        init=False,
+        default="CLI default output format (json if not specified) [{default}]: ",
     )
 
 
@@ -815,7 +819,7 @@ def write_aws_config(aws_config, lines):
 
 
 def assert_aws_config(aws_config, expected_lines):
-    with open(aws_config, "r") as f:
+    with open(aws_config) as f:
         assert f.read().splitlines() == expected_lines
 
 
@@ -902,7 +906,10 @@ class TestConfigureSSOCommand:
         )
         stdout = capsys.readouterr().out
         assert "WARNING: Configuring using legacy format" in stdout
-        assert f"aws sts get-caller-identity --profile {inputs.profile_prompt.answer}" in stdout
+        assert (
+            f"aws sts get-caller-identity --profile {inputs.profile_prompt.answer}"
+            in stdout
+        )
 
     def test_single_account_single_role_flow_no_browser(
         self,
@@ -1103,7 +1110,7 @@ class TestConfigureSSOCommand:
         assert_aws_config(
             aws_config,
             expected_lines=[
-                f"[profile new-profile]",
+                "[profile new-profile]",
                 f"sso_start_url = {inputs.start_url_prompt.answer}",
                 f"sso_region = {inputs.sso_region_prompt.answer}",
                 f"sso_account_id = {account_id}",
@@ -1236,7 +1243,10 @@ class TestConfigureSSOCommand:
         )
         stdout = capsys.readouterr().out
         assert "WARNING: Configuring using legacy format" not in stdout
-        assert f"aws sts get-caller-identity --profile {inputs.profile_prompt.answer}" in stdout
+        assert (
+            f"aws sts get-caller-identity --profile {inputs.profile_prompt.answer}"
+            in stdout
+        )
 
     def test_configure_sso_with_existing_sso_session(
         self,
@@ -1514,32 +1524,55 @@ class TestConfigureSSOCommand:
             ],
         )
 
+
 class TestPrintConclusion:
-    def test_print_conclusion_default_profile_with_credentials(self, sso_cmd, capsys):
+    def test_print_conclusion_default_profile_with_credentials(
+        self, sso_cmd, capsys
+    ):
         sso_cmd._print_conclusion(True, 'default')
         captured = capsys.readouterr()
-        assert "The AWS CLI is now configured to use the default profile." in captured.out
+        assert (
+            "The AWS CLI is now configured to use the default profile."
+            in captured.out
+        )
         assert "aws sts get-caller-identity" in captured.out
 
-    def test_print_conclusion_named_profile_with_credentials(self, sso_cmd, capsys):
+    def test_print_conclusion_named_profile_with_credentials(
+        self, sso_cmd, capsys
+    ):
         profile_name = "test-profile"
         sso_cmd._print_conclusion(True, profile_name)
         captured = capsys.readouterr()
-        assert f"To use this profile, specify the profile name using --profile" in captured.out
-        assert f"aws sts get-caller-identity --profile {profile_name}" in captured.out
+        assert (
+            "To use this profile, specify the profile name using --profile"
+            in captured.out
+        )
+        assert (
+            f"aws sts get-caller-identity --profile {profile_name}"
+            in captured.out
+        )
 
     def test_print_conclusion_sso_configuration(self, sso_cmd, capsys):
         profile_name = "test-profile"
         sso_cmd._print_conclusion(False, profile_name)
         captured = capsys.readouterr()
-        assert f"Successfully configured SSO for profile: {profile_name}" in captured.out
+        assert (
+            f"Successfully configured SSO for profile: {profile_name}"
+            in captured.out
+        )
 
-    def test_print_conclusion_default_profile_case_insensitive(selfself, sso_cmd, capsys):
+    def test_print_conclusion_default_profile_case_insensitive(
+        selfself, sso_cmd, capsys
+    ):
         sso_cmd._print_conclusion(True, 'DEFAULT')
         captured = capsys.readouterr()
-        assert "The AWS CLI is now configured to use the default profile." in captured.out
+        assert (
+            "The AWS CLI is now configured to use the default profile."
+            in captured.out
+        )
         assert "aws sts get-caller-identity" in captured.out
 
+
 class TestConfigureSSOSessionCommand:
     def test_new_sso_session(
         self,
@@ -1614,7 +1647,8 @@ class TestConfigureSSOSessionCommand:
         sso_session_cmd = sso_session_cmd_factory(session=StubbedSession())
         sso_session_cmd(args, parsed_globals)
         assert_aws_config(
-            aws_config, expected_lines=aws_config_lines_for_existing_sso_session
+            aws_config,
+            expected_lines=aws_config_lines_for_existing_sso_session,
         )
 
     def test_override_existing_sso_session_configurations(
@@ -1716,7 +1750,9 @@ class TestPTKPrompt(unittest.TestCase):
 
     def test_can_provide_toolbar(self):
         toolbar = "Toolbar content"
-        self.prompter.get_value("default_value", "Prompt Text", toolbar=toolbar)
+        self.prompter.get_value(
+            "default_value", "Prompt Text", toolbar=toolbar
+        )
         self.assert_expected_toolbar(toolbar)
 
     def test_can_provide_prompt_format(self):
@@ -1842,9 +1878,9 @@ class TestSSOSessionConfigurationPrompter:
     def test_prompt_for_start_url_reuse_existing_configuration(
         self, sso_config_prompter, ptk_stubber, existing_start_url
     ):
-        sso_config_prompter.sso_session_config[
-            "sso_start_url"
-        ] = existing_start_url
+        sso_config_prompter.sso_session_config["sso_start_url"] = (
+            existing_start_url
+        )
         ptk_stubber.user_inputs = UserInputs(
             start_url_prompt=StartUrlPrompt(
                 "", expected_default=existing_start_url
@@ -1889,9 +1925,9 @@ class TestSSOSessionConfigurationPrompter:
     def test_prompt_for_sso_region_reuse_existing_configuration(
         self, sso_config_prompter, ptk_stubber, existing_sso_region
     ):
-        sso_config_prompter.sso_session_config[
-            "sso_region"
-        ] = existing_sso_region
+        sso_config_prompter.sso_session_config["sso_region"] = (
+            existing_sso_region
+        )
         ptk_stubber.user_inputs = UserInputs(
             sso_region_prompt=SSORegionPrompt(
                 "", expected_default=existing_sso_region
@@ -1933,9 +1969,9 @@ class TestSSOSessionConfigurationPrompter:
     def test_prompt_for_scopes_reuse_existing_configuration(
         self, sso_config_prompter, ptk_stubber, existing_scopes
     ):
-        sso_config_prompter.sso_session_config[
-            "sso_registration_scopes"
-        ] = existing_scopes
+        sso_config_prompter.sso_session_config["sso_registration_scopes"] = (
+            existing_scopes
+        )
         ptk_stubber.user_inputs = UserInputs(
             scopes_prompt=ScopesPrompt("", expected_default=existing_scopes)
         )
